@@ -5,7 +5,13 @@ from typing import List, cast, Type
 
 from grobid_client import Client
 from grobid_client.api.pdf import process_fulltext_document
-from grobid_client.models import ProcessForm, Article, TextWithRefs, Citation, ArticleCitations
+from grobid_client.models import (
+    ProcessForm,
+    Article,
+    TextWithRefs,
+    Citation,
+    ArticleCitations,
+)
 from grobid_client.types import File, TEI
 from pydantic import Field, BaseModel
 from pymultirole_plugins.v1.converter import ConverterParameters, ConverterBase
@@ -14,30 +20,39 @@ from starlette.datastructures import UploadFile
 
 # _home = os.path.expanduser('~')
 # xdg_cache_home = os.environ.get('XDG_CACHE_HOME') or os.path.join(_home, '.cache')
-APP_GROBID_URI = os.environ.get('APP_GROBID_URI', "https://entityfishing.kairntech.com/grobid/grobid")
+APP_GROBID_URI = os.environ.get(
+    "APP_GROBID_URI", "https://entityfishing.kairntech.com/grobid/grobid"
+)
 
 
 class GrobidParameters(ConverterParameters):
-    sourceText: bool = Field(False, description='Set source text in conversion output')
-    sentences: bool = Field(False, description='Force sentence segmentation')
-    figures: bool = Field(False, description='Do extract figures and tables descriptions')
-    citations: bool = Field(False, description='Do extract bibliographic references in text')
+    sourceText: bool = Field(False, description="Set source text in conversion output")
+    sentences: bool = Field(False, description="Force sentence segmentation")
+    figures: bool = Field(
+        False, description="Do extract figures and tables descriptions"
+    )
+    citations: bool = Field(
+        False, description="Do extract bibliographic references in text"
+    )
 
 
 class GrobidConverter(ConverterBase):
-    """Grodbid PDF converter .
-    """
+    """Grodbid PDF converter ."""
 
-    def convert(self, source: UploadFile, parameters: ConverterParameters) \
-            -> List[Document]:
-        params: GrobidParameters = \
-            cast(GrobidParameters, parameters)
+    def convert(
+        self, source: UploadFile, parameters: ConverterParameters
+    ) -> List[Document]:
+        params: GrobidParameters = cast(GrobidParameters, parameters)
 
         client = get_client()
         doc = None
         form = ProcessForm(
             segment_sentences="1" if params.sentences else "0",
-            input_=File(file_name=source.filename, payload=source.file, mime_type=source.content_type),
+            input_=File(
+                file_name=source.filename,
+                payload=source.file,
+                mime_type=source.content_type,
+            ),
         )
         r = process_fulltext_document.sync_detailed(client=client, multipart_data=form)
         if r.is_success:
@@ -64,21 +79,21 @@ def article_to_doc(response, params):
 def citation_to_metadata(citation: Citation):
     metadata = {}
     if citation.main_title:
-        metadata['main_title'] = str(citation.main_title)
+        metadata["main_title"] = str(citation.main_title)
     if citation.published:
-        metadata['published'] = str(citation.published)
+        metadata["published"] = str(citation.published)
     if citation.publisher:
-        metadata['publisher'] = citation.publisher
+        metadata["publisher"] = citation.publisher
     if citation.ids:
         for k, v in citation.ids.additional_properties.items():
             metadata[k] = v
     if citation.authors:
         authors, affiliations = authors_and_affiliations(citation.authors)
-        metadata['authors'] = authors
-        metadata['affiliations'] = affiliations
+        metadata["authors"] = authors
+        metadata["affiliations"] = affiliations
     if citation.titles:
         for k, v in citation.titles.additional_properties.items():
-            metadata['title_' + k] = v
+            metadata["title_" + k] = v
     if citation.scopes:
         for k, v in citation.scopes.additional_properties.items():
             metadata[k] = v
@@ -115,7 +130,7 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
     ref2citations = {}
     if params.citations and citations:
         for ref, citation in citations.additional_properties.items():
-            ref2citations['#' + ref] = citation_to_metadata(citation)
+            ref2citations["#" + ref] = citation_to_metadata(citation)
     if sections:
         text_buf = []
         sentences = []
@@ -131,7 +146,9 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
                 for paragraph in section.paragraphs:
                     if params.sentences:
                         for i, sentence in enumerate(paragraph):
-                            sent, annots = add_references(sentence, text_buf, ref2citations)
+                            sent, annots = add_references(
+                                sentence, text_buf, ref2citations
+                            )
                             sentences.append(sent)
                             if params.citations:
                                 annotations.extend(annots)
@@ -139,7 +156,9 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
                                 text_buf.append(" ")
                         text_buf.append("\n")
                     else:
-                        sent, annots = add_references(paragraph, text_buf, ref2citations)
+                        sent, annots = add_references(
+                            paragraph, text_buf, ref2citations
+                        )
                         sentences.append(sent)
                         if params.citations:
                             annotations.extend(annots)
@@ -162,13 +181,19 @@ def add_references(sentence: TextWithRefs, text_buf: List[str], ref2citations):
     if sentence.refs:
         for ref in sentence.refs:
             if ref.type == "bibr":
-                a = Annotation(label="Citation", labelName="citation",
-                               text=sentence.text[ref.start:ref.end],
-                               start=start + ref.start, end=start + ref.end)
+                a = Annotation(
+                    label="Citation",
+                    labelName="citation",
+                    text=sentence.text[ref.start : ref.end],
+                    start=start + ref.start,
+                    end=start + ref.end,
+                )
                 props = ref2citations.get(ref.target, None)
                 if props:
-                    term_id = props.pop('main_title', 'Unknown')
-                    a.terms = [Term(identifier=term_id, lexicon="grobid", properties=props)]
+                    term_id = props.pop("main_title", "Unknown")
+                    a.terms = [
+                        Term(identifier=term_id, lexicon="grobid", properties=props)
+                    ]
                 annotations.append(a)
     return Sentence(start=start, end=end), annotations
 
